@@ -179,6 +179,9 @@ class Connection(object):
     def getColumns(self, database, table):
         return self.get_columns(database, table)
 
+    def get_schema_names(self, database, table):
+        return self._client.getSchemaNames()
+
     def commit(self):
         """Hive does not support transactions, so this does nothing."""
         pass
